#include "..\script_component.hpp"

/*
 * Function: forge_client_org_fnc_leave
 * Author: IDSolutions
 *
 * [Description]
 * Removes the current player from an organization.
 * This allows a member to leave their organization voluntarily.
 * Organization owners cannot use this function and must use disband instead.
 *
 * Arguments:
 * None
 *
 * Return Value:
 * Success <BOOLEAN> - True if player successfully left the organization, false otherwise
 *
 * Example:
 * [] call forge_client_org_fnc_leave
 *
 * Public: Yes
 */

// Get the organization store interface
private _store = call FUNC(verifyOrgStore);

// Attempt to leave the organization
// This will validate that the player is not the owner and handle database updates
private _result = _store call ["leaveOrg", []];

// Provide feedback based on success or failure
if (_result) then {
    ["You have left the organization", "success", 5, "right"] call forge_client_misc_fnc_notify;
} else {
    ["Failed to leave organization", "error", 5, "right"] call forge_client_misc_fnc_notify;
};

// Return the result for further operations
_result